@@ -1,4 +1,4 @@
-import deskbar.handler, deskbar.handler_utils
+import deskbar.Handler, deskbar.Utils
 
 def _on_more():
 	print "More..."
@@ -7,12 +7,12 @@ def _check_requirements():
 	import os.path
 	if os.path.exists(os.path.expanduser("~/foo")):
 		print "DebugRequirementsModule: Requirements met"
-		return (deskbar.handler.HANDLER_IS_HAPPY, None, None)
+		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 	else:
 		print "DebugRequirementsModule: Requirements not met"
-		return (deskbar.handler.HANDLER_HAS_REQUIREMENTS,
+		return (deskbar.Handler.HANDLER_HAS_REQUIREMENTS,
 			'You need to create a file called "~/foo"',
-			lambda: deskbar.handler_utils.more_information_dialog(
+			lambda: deskbar.Utils.more_information_dialog(
 			"Debug Requirements Title",
 			"Debug Requirements Content"
 			))
@@ -24,22 +24,22 @@ HANDLERS = {
 	}
 }
 
-class DebugRequirementsMatch(deskbar.handler.Match):
-	def __init__(self, handler, name, icon=None):
-		deskbar.handler.Match.__init__ (self, handler, name)
+class DebugRequirementsMatch(deskbar.Match.Match):
+	def __init__(self, handler, **args):
+		deskbar.Match.Match.__init__ (self, handler, **args)
 	
 	def get_verb(self):
 		return "%(name)s - %(text)s"
 		
 	def action(self, text=None):
 		pass
-
-class DebugRequirementsModule(deskbar.handler.Handler):
-	def __init__ (self):
-		deskbar.handler.Handler.__init__ (self, "stock_script")
 		
-	def query (self, qstring, max):
-		if max > 0:
-			return [DebugRequirementsMatch(self, "TestMatch")]
-		else:
-			return []	
+	def get_category (self):
+		return "debug"
+
+class DebugRequirementsModule(deskbar.Handler.Handler):
+	def __init__ (self):
+		deskbar.Handler.Handler.__init__ (self, "stock_script")
+		
+	def query (self, qstring):
+		return [DebugRequirementsMatch(self, name="TestMatch")]
