@@ -1,6 +1,6 @@
-import deskbar.handler
-
-import os
+import deskbar.Handler, deskbar
+from deskbar.Utils import strip_html
+import os, cgi
 import gobject
 import gnomevfs
 from os.path import expanduser, exists, join
@@ -29,44 +29,47 @@ Now download the developers kit and extract the GoogleSearch.wsdl file from it.
 ~/.gnome2/deskbar-applet/GoogleSearch.wsdl""")
 
 def _on_more_information():
-	deskbar.handler_utils.more_information_dialog(_("Setting Up Google Live"), HELP_TEXT)
+	deskbar.Utils.more_information_dialog(_("Setting Up Google Live"), HELP_TEXT)
 
 def _check_requirements():
 	try:
 		from SOAPpy import WSDL
 	except:
-		return (deskbar.handler.HANDLER_IS_NOT_APPLICABLE, _("You need to install the SOAPpy python module."), None)
+		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, _("You need to install the SOAPpy python module."), None)
 	if not exists (GOOGLE_WSDL):
-		return (deskbar.handler.HANDLER_HAS_REQUIREMENTS, _("You need the Google WSDL file."), _on_more_information)
+		return (deskbar.Handler.HANDLER_HAS_REQUIREMENTS, _("You need the Google WSDL file."), _on_more_information)
 	if not exists (GOOGLE_API_KEY):
-		return (deskbar.handler.HANDLER_HAS_REQUIREMENTS, _("You need a Google API key."), _on_more_information)
+		return (deskbar.Handler.HANDLER_HAS_REQUIREMENTS, _("You need a Google API key."), _on_more_information)
 	else:
-		return (deskbar.handler.HANDLER_IS_HAPPY, None, None)
+		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 		
 HANDLERS = {
 	"GoogleLiveHandler" : {
-		"name": _("Google Live"),
+		"name": _("Google Search"),
 		"description": _("Search Google as you type"),
 		"requirements" : _check_requirements
 	}
 }
 
 
-class GoogleMatch (deskbar.handler.Match):
-	def __init__(self, handler, name, url, icon=None):
-		deskbar.handler.Match.__init__ (self, handler, "Google Live: "+name, icon)
-		self.__url = url
+class GoogleMatch (deskbar.Match.Match):
+	def __init__(self, handler, name, url, **args):
+		deskbar.Match.Match.__init__ (self, handler, name=name, **args)
+		self.url = url
 	
 	def get_verb(self):
 		return "%(name)s"
 		
 	def action(self, text=None):
-		gnomevfs.url_show(self.__url)
+		gnomevfs.url_show(self.url)
+		
+	def get_category(self):
+		return "web"
 	
 	def get_hash(self, text=None):
-		return self.__url
+		return self.url
 
-class GoogleLiveHandler (deskbar.handler.AsyncHandler):
+class GoogleLiveHandler (deskbar.Handler.AsyncHandler):
 	"""
 	This handler requires the user to have a valid Google account, a Google
 	API key and a GoogleSearch.wsdl file. The file locations are specified
@@ -75,27 +78,39 @@ class GoogleLiveHandler (deskbar.handler.AsyncHandler):
 	It uses SOAPpy to interact with Googles SOAP inteface.
 	"""
 	def __init__ (self):
-		deskbar.handler.AsyncHandler.__init__ (self, "google.png")
+		deskbar.Handler.AsyncHandler.__init__ (self, "google.png")
 		self.server = None
 		self.api_key = None
 		
-	def initialize (self):
+	def initialize (self):                        
 		self.server = WSDL.Proxy (GOOGLE_WSDL)
+		
+		try:
+			proxy = os.environ['http_proxy']
+			if proxy.startswith('http://'):
+				proxy = proxy[len('http://'):]
+				
+			self.server.soapproxy.http_proxy = proxy
+			print "Using http_proxy '%s' for google live" % proxy
+		except KeyError:
+			pass
+			
 		api_key_file = file (GOOGLE_API_KEY)
 		self.api_key = api_key_file.readline()
 		api_key_file.close ()
 			
-	def query (self, qstring, qmax=5):
+	def query (self, qstring):
 		"""Behold the true power of the AsyncHandler!"""
 		
 		# Just to ensure we don't bork anything
-		qmax = min (qmax, MAX_QUERIES)
+		qmax = min (deskbar.DEFAULT_RESULTS_PER_HANDLER, MAX_QUERIES)
 		
 		# Delay before we query so we *don't* make four queries
 		# "s", "sp", "spa", "spam".
 		self.check_query_changed (timeout=QUERY_DELAY)
 		
-		print "GoogleLive: Querying Google for", qstring
+		#print "GoogleLive: Querying Google for", qstring
+		print 'Query google for:', qstring
 		results = self.server.doGoogleSearch (self.api_key, # personal google api key
 						qstring, 	# query
 						0, qmax, 	# start/end of result list
@@ -104,13 +119,17 @@ class GoogleLiveHandler (deskbar.handler.AsyncHandler):
 						False, 		# safe search (filter adult material)
 						"", 		# get results in specific language
 						"utf-8", "utf-8") # input/output encodings
-					
+		print 'Got google answer for:', qstring
+		
 		# The google search might have taken a long time
 		# better check if we're still valid	
 		self.check_query_changed ()
-		return [
-			GoogleMatch (self, r.title.encode("utf-8"), 
+		matches = [
+			GoogleMatch (self, cgi.escape(strip_html(r.title.encode("utf-8"))), 
 					#r.snippet.encode("utf-8"),  # We don't use the description
 					r.URL.encode ("utf-8"))
 			for r in results.resultElements[:qmax-1]
-		]
+			]
+		self.check_query_changed ()
+		print "Returning google answer for:", qstring
+		return matches
