@@ -80,6 +80,7 @@ class GenericProgramMatch(deskbar.Match.Match):
 class GnomeDictMatch(GenericProgramMatch):
 	def __init__(self, backend, use_arg=True, **args):
 		GenericProgramMatch.__init__(self, backend, use_arg=use_arg, **args)
+		self._args = ["--look-up"]
 	
 	def get_verb(self):
 		return _("Lookup %s in dictionary") % "<b>%(text)s</b>"
@@ -106,7 +107,7 @@ class SpecialProgramHandler(deskbar.Handler.Handler):
 	def create_match(self, desktop, f):
 		raise NotImplementedError
 		
-	def query(self, qstring, qmax):
+	def query(self, qstring):
 		if self._match != None:
 			return [self._match]
 		else:
@@ -144,8 +145,8 @@ class ProgramsHandler(deskbar.Handler.Handler):
 	def initialize(self):
 		self._scan_desktop_files()
 		
-	def query(self, query, max):
-		return self._indexer.look_up(query)[:max]
+	def query(self, query):
+		return self._indexer.look_up(query)[:deskbar.DEFAULT_RESULTS_PER_HANDLER]
 		
 	def _scan_desktop_files(self):
 		for dir in get_xdg_data_dirs():
@@ -179,7 +180,12 @@ def parse_desktop_filename(desktop, only_if_visible=True):
 
 
 def parse_desktop_file(desktop, only_if_visible=True):
-	desktop = deskbar.gnomedesktop.item_new_from_file(desktop, deskbar.gnomedesktop.LOAD_ONLY_IF_EXISTS)
+	try:
+		desktop = deskbar.gnomedesktop.item_new_from_file(desktop, deskbar.gnomedesktop.LOAD_ONLY_IF_EXISTS)
+	except Exception, e:
+		print 'Couldn\'t read desktop file:%s:%s' % (desktop, e)
+		return None
+	
 	if desktop == None or desktop.get_entry_type() != deskbar.gnomedesktop.TYPE_APPLICATION:
 		return None
 	if desktop.get_boolean(deskbar.gnomedesktop.KEY_TERMINAL):
